@@ -229,12 +229,12 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
         self,
         module_name: str,
         function: Union[Callable[..., float], Callable[..., Iterable[float]]],
-        compounds: List[str] = None,
-        derived_compounds: List[str] = None,
-        modifiers: List[str] = None,
-        parameters: List[str] = None,
-        dynamic_variables: List[str] = None,
-        args: List[str] = None,
+        compounds: List[str] | None = None,
+        derived_compounds: List[str] | None = None,
+        modifiers: List[str] | None = None,
+        parameters: List[str] | None = None,
+        dynamic_variables: List[str] | None = None,
+        args: List[str] | None = None,
         check_consistency: bool = True,
         sort_modules: bool = True,
         **meta_info: Dict[str, Any],
@@ -306,7 +306,7 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
         if sort_modules:
             self._sort_algebraic_modules()
 
-    def add_algebraic_modules(self, algebraic_modules: dict, meta_info: dict = None) -> None:
+    def add_algebraic_modules(self, algebraic_modules: dict, meta_info: dict | None = None) -> None:
         """Add multiple algebraic modules to the model.
 
         See Also
@@ -321,13 +321,13 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
     def update_algebraic_module(
         self,
         module_name: str,
-        function: Union[Callable[..., float], Callable[..., Iterable[float]]] = None,
-        compounds: List[str] = None,
-        derived_compounds: List[str] = None,
-        modifiers: List[str] = None,
-        parameters: List[str] = None,
-        dynamic_variables: List[str] = None,
-        args: List[str] = None,
+        function: Union[Callable[..., float], Callable[..., Iterable[float]]] | None = None,
+        compounds: List[str] | None = None,
+        derived_compounds: List[str] | None = None,
+        modifiers: List[str] | None = None,
+        parameters: List[str] | None = None,
+        dynamic_variables: List[str] | None = None,
+        args: List[str] | None = None,
         check_consistency: bool = True,
         sort_modules: bool = True,
     ) -> None:
