@@ -147,6 +147,8 @@ class CompoundMixin(BaseModel):
         compounds_modelbase_code : str
             Source code generating the modelbase compounds
         """
+        if len(self.compounds) == 0:
+            return ""
         if include_meta_info:
             meta_info = self._get_nonzero_meta_info(component="compounds")
             if bool(meta_info):
