@@ -97,12 +97,12 @@ def _get_plot_kwargs(
 def _style_subplot(
     ax: Axis,
     kwargs: dict,
-    xlabel: str = None,
-    ylabel: str = None,
-    zlabel: str = None,
-    title: str = None,
+    xlabel: str | None = None,
+    ylabel: str | None = None,
+    zlabel: str | None = None,
+    title: str | None = None,
     legend: bool = False,
-    grid: bool = None,
+    grid: bool | None = None,
 ) -> None:
     """Set style of the subplot."""
     if grid:
@@ -188,7 +188,7 @@ def plot_grid(
     sharey: bool = True,
     xlabels: Optional[Union[str, Iterable[str]]] = None,
     ylabels: Optional[Union[str, Iterable[str]]] = None,
-    figure_title: str = None,
+    figure_title: str | None = None,
     plot_titles: Optional[Union[Iterable[str], Iterable[None]]] = None,
     grid: bool = True,
     tight_layout: bool = True,
@@ -311,7 +311,7 @@ def heatmap_from_dataframe(
     cmap: str = "viridis",
     vmax: Optional[float] = None,
     vmin: Optional[float] = None,
-    norm: plt.Normalize = None,
+    norm: plt.Normalize | None = None,
     ax: Optional[Axis] = None,
     cax: Optional[Axis] = None,
     sci_annotation_bounds: Tuple[float, float] = (0.01, 100),
